summaryrefslogtreecommitdiffstats
path: root/kdat/BackupDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/BackupDlg.h')
-rw-r--r--kdat/BackupDlg.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kdat/BackupDlg.h b/kdat/BackupDlg.h
index cf32bef..0cbc61c 100644
--- a/kdat/BackupDlg.h
+++ b/kdat/BackupDlg.h
@@ -33,10 +33,11 @@ class Tape;
class TarParser;
/**
- * @short Status dialog for backing up files.
+ * @short tqStatus dialog for backing up files.
*/
class BackupDlg : public TQDialog {
Q_OBJECT
+ TQ_OBJECT
KProcess* _proc;
TarParser* _tarParser;
TQString _archiveName;
@@ -92,12 +93,12 @@ public:
* @param removeSnapshot Remove the snapshot before backing up.
* @param archiveSize The estimate size of the archive in kilobytes.
* @param tape The tape index to add the archive to.
* @param parent The parent widget for this dialog.
* @param name The name of this widget.
*/
BackupDlg( const TQString & archiveName, const TQString & workingDir, const TQStringList& files, bool oneFilesystem, bool incremental,
const TQString & snapshot, bool removeSnapshot, int archiveSize, Tape* tape,
- TQWidget* parent = 0, const char* name = 0 );
+ TQWidget* tqparent = 0, const char* name = 0 );
/**
* Destroy the backup dialog.
@@ -92,12 +93,12 @@ public:
* @param archiveSize The estimate size of the archive in kilobytes.
* @param tape The tape index to add the archive to.
- * @param parent The parent widget for this dialog.
+ * @param tqparent The tqparent widget for this dialog.
* @param name The name of this widget.
*/